@@ -32,10 +32,7 @@ import cdktf._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdktf/tf-module-stack",
-    "5.0.49",
-    __name__[0:-6],
-    "tf-module-stack@5.0.49.jsii.tgz",
+    "@cdktf/tf-module-stack", "6.0.1", __name__[0:-6], "tf-module-stack@6.0.1.jsii.tgz"
 )
 
 __all__ = [
